@@ -28,12 +28,22 @@
 G_BEGIN_DECLS
 
 int gbf_build_run (GbfAmProject    *project,
-		   GbfBuildType     type,
+		   gchar           *id,
 		   const char      *project_dir,
 		   GList           *callbacks);
 
 void gbf_build_cancel (int build_id);
 
+
+/* Build ID for default targets */
+#define GBF_AM_BUILD_ID_ALL 		"ALL"
+#define GBF_AM_BUILD_ID_INSTALL 	"INSTALL"
+#define GBF_AM_BUILD_ID_CLEAN 		"CLEAN"
+#define GBF_AM_BUILD_ID_AUTOGEN 	"AUTOGEN"
+#define GBF_AM_BUILD_ID_CONFIGURE 	"CONFIGURE"
+
+#define GBF_AM_BUILD_ID_USER_PREFIX 	"USER:"
+
 G_END_DECLS
 
 #endif /* _GBF_AM_BUILD_H_ */
