@@ -1080,13 +1080,13 @@ gbf_am_properties_get_group_widget (GbfAmProject *project,
 	add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
 				_("C compiler flags:"), NULL, "amcflags", table_cflags, 0);
 	add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
-				_("C preprocessor flags"), NULL, "amcppflags", table_cflags, 1);
+				_("C preprocessor flags:"), NULL, "amcppflags", table_cflags, 1);
 	add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
-				_("C++ compiler flags"), NULL, "amcxxflags", table_cflags, 2);
+				_("C++ compiler flags:"), NULL, "amcxxflags", table_cflags, 2);
 	add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
-				_("gcj compiler flags (ahead-of-time)"), NULL, "amgcjflags", table_cflags, 3);
+				_("gcj compiler flags (ahead-of-time):"), NULL, "amgcjflags", table_cflags, 3);
 	add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
-				_("Java compiler flags (just-in-time)"), NULL, "amjavaflags", table_cflags, 4);
+				_("Java compiler flags (just-in-time):"), NULL, "amjavaflags", table_cflags, 4);
 	add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
 				_("Fortran compiler flags:"), NULL, "amfflags", table_cflags, 5);
 				
